@@ -1,10 +1,10 @@
 #ifndef JSON_SPIRIT_READER_TEMPLATE
 #define JSON_SPIRIT_READER_TEMPLATE
 
-//          Copyright John W. Wilkinson 2007 - 2011
+//          Copyright John W. Wilkinson 2007 - 2013
 // Distributed under the MIT License, see accompanying file LICENSE.txt
 
-// json spirit version 4.05
+// json spirit version 4.06
 
 #if defined(_MSC_VER) && (_MSC_VER >= 1020)
 # pragma once
@@ -250,21 +250,21 @@ namespace json_spirit
 
         void new_str( Iter_type begin, Iter_type end )
         {
-            add_to_current( get_str< String_type >( begin, end ) );
+            add_to_current( Value_type(get_str< String_type >( begin, end )) );
         }
 
         void new_true( Iter_type begin, Iter_type end )
         {
             assert( is_eq( begin, end, "true" ) );
 
-            add_to_current( true );
+            add_to_current( Value_type(true) );
         }
 
         void new_false( Iter_type begin, Iter_type end )
         {
             assert( is_eq( begin, end, "false" ) );
 
-            add_to_current( false );
+            add_to_current( Value_type(false) );
         }
 
         void new_null( Iter_type begin, Iter_type end )
@@ -276,17 +276,17 @@ namespace json_spirit
 
         void new_int( boost::int64_t i )
         {
-            add_to_current( i );
+            add_to_current( Value_type(i) );
         }
 
         void new_uint64( boost::uint64_t ui )
         {
-            add_to_current( ui );
+            add_to_current( Value_type(ui) );
         }
 
         void new_real( double d )
         {
-            add_to_current( d );
+            add_to_current( Value_type(d) );
         }
 
     private:
@@ -488,7 +488,7 @@ namespace json_spirit
                     ;
 
                 string_ 
-                    = lexeme_d // this causes white space inside a string to be retained
+                    = lexeme_d // this causes white space and what would appear to be comments inside a string to be retained
                       [
                           confix_p
                           ( 
@@ -564,7 +564,9 @@ namespace json_spirit
         const spirit_namespace::parse_info< Iter_type > info = 
                             spirit_namespace::parse( begin, end, 
                                                     Json_grammer< Value_type, Iter_type >( semantic_actions ), 
-                                                    spirit_namespace::space_p );
+                                                    spirit_namespace::space_p | 
+                                                    spirit_namespace::comment_p("//") | 
+                                                    spirit_namespace::comment_p("/*", "*/") );
 
         if( !info.hit )
         {
